==> adminer_3.3.3.orig.tar.gz: adminer-3.3.3/adminer/lang/es.inc.php <==
<?php
$translations = array(
	'Login' => 'Login',
	'Logout successful.' => 'Salida exitosa.',
	'Invalid credentials.' => 'Identificacion inválida.',
	'Server' => 'Servidor',
	'Username' => 'Usuario',
	'Password' => 'Contraseña',
	'Select database' => 'Seleccionar Base de datos',
	'Invalid database.' => 'Base de datos inválida.',
	'Create new database' => 'Ingrese nueva base de datos',
	'Table has been dropped.' => 'Tabla eliminada.',
	'Table has been altered.' => 'Tabla modificada.',
	'Table has been created.' => 'Tabla creada.',
	'Alter table' => 'Modifique estructura',
	'Create table' => 'Cree tabla',
	'Table name' => 'Nombre de la tabla',
	'engine' => 'motor',
	'collation' => 'colación',
	'Column name' => 'Nombre de columna',
	'Type' => 'Tipo',
	'Length' => 'Longitud',
	'Auto Increment' => 'Incremento automático',
	'Options' => 'Opciones',
	'Save' => 'Guardar',
	'Drop' => 'Eliminar',
	'Database has been dropped.' => 'Base de datos eliminada.',
	'Database has been created.' => 'Base de datos creada.',
	'Database has been renamed.' => 'Base de datos renombrada.',
	'Database has been altered.' => 'Base de datos modificada.',
	'Alter database' => 'Modificar Base de datos',
	'Create database' => 'Crear Base de datos',
	'SQL command' => 'Comando SQL',
	'Dump' => 'Export',
	'Logout' => 'Logout',
	'database' => 'base de datos',
	'Use' => 'Usar',
	'No tables.' => 'No existen tablas.',
	'select' => 'registros',
	'Create new table' => 'Nueva tabla',
	'Item has been deleted.' => 'Registro eliminado.',
	'Item has been updated.' => 'Registro modificado.',
	'Item%s has been inserted.' => 'Registro%s insertado.',
	'Edit' => 'Modificar',
	'Insert' => 'Agregar',
	'Save and insert next' => 'Guardar e insertar otro',
	'Delete' => 'Eliminar',
	'Database' => 'Base de datos',
	'Routines' => 'Procedimientos',
	'Indexes have been altered.' => 'Indices modificados.',
	'Indexes' => 'Indices',
	'Alter indexes' => 'Modificar indices',
	'Add next' => 'Agregar',
	'Language' => 'Idioma',
	'Select' => 'Mostrar',
	'New item' => 'Nuevo Registro',
	'Search' => 'Condición',
	'Sort' => 'Ordenar',
	'descending' => 'descendiente',
	'Limit' => 'Limit',
	'No rows.' => 'No existen registros.',
	'Action' => 'Acción',
	'edit' => 'modificar',
	'Page' => 'Página',
	'Query executed OK, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Error in query' => 'Error en consulta',
	'Execute' => 'Ejecutar',
	'Table' => 'Tabla',
	'Foreign keys' => 'Claves foráneas',
	'Triggers' => 'Triggers',
	'View' => 'Vistas',
	'Unable to select the table' => 'No es posible seleccionar la tabla',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF inválido. Vuelva a enviar los datos del formulario.',
	'Comment' => 'Comentario',
	'Default values' => 'Valores predeterminados',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'No hay comando para ejecutar.',
	'Unable to upload a file.' => 'No es posible importar archivo.',
	'File upload' => 'Importar archivo',
	'File uploads are disabled.' => 'Importación de archivos deshablilitado.',
	'Routine has been called, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Call' => 'Llamar',
	'No extension' => 'No hay extension',
	'None of the supported PHP extensions (%s) are available.' => 'Ninguna de las extensiones PHP soportadas (%s) está disponible.',
	'Session support must be enabled.' => 'Deben estar habilitadas las sesiones.',
	'Session expired, please login again.' => 'Sesión expirada, por favor ingrese su clave de nuevo.',
	'Text length' => 'Longitud de texto',
	'Foreign key has been dropped.' => 'Clave externa eliminada.',
	'Foreign key has been altered.' => 'Clave externa modificada.',
	'Foreign key has been created.' => 'Clave externa creada.',
	'Foreign key' => 'Clave externa',
	'Target table' => 'Tabla de destino',
	'Change' => 'Modificar',
	'Source' => 'Origen',
	'Target' => 'Destino',
	'Add column' => 'Agregar columna',
	'Alter' => 'Modificar',
	'Add foreign key' => 'Agregar clave foránea',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => 'Tipo de índice',
	'Column (length)' => 'Columna (longitud)',
	'View has been dropped.' => 'Vista eliminada.',
	'View has been altered.' => 'Vista modificada.',
	'View has been created.' => 'Vista creada.',
	'Alter view' => 'Modificar vista',
	'Create view' => 'Cear vista',
	'Name' => 'Nombre',
	'Process list' => 'Lista de procesos',
	'%d process(es) have been killed.' => array('%d proceso detenido.', '%d procesos detenidos.'),
	'Kill' => 'Detener',
	'Parameter name' => 'Nombre de Parámetro',
	'Database schema' => 'Esquema de base de datos',
	'Create procedure' => 'Crear procedimiento',
	'Create function' => 'Crear función',
	'Routine has been dropped.' => 'Procedimiento eliminado.',
	'Routine has been altered.' => 'Procedimiento modificado.',
	'Routine has been created.' => 'Procedimiento creado.',
	'Alter function' => 'Modificar Función',
	'Alter procedure' => 'Modificar procedimiento',
	'Return type' => 'Tipo de valor de regreso',
	'Add trigger' => 'Agregar trigger',
	'Trigger has been dropped.' => 'Trigger eliminado.',
	'Trigger has been altered.' => 'Trigger modificado.',
	'Trigger has been created.' => 'Trigger creado.',
	'Alter trigger' => 'Modificar Trigger',
	'Create trigger' => 'Agregar Trigger',
	'Time' => 'Tiempo',
	'Event' => 'Evento',
	'%s version: %s through PHP extension %s' => 'Versión %s: %s a través de extensión PHP %s',
	'%d row(s)' => array('%d registro', '%d registros'),
	'Remove' => 'Eliminar',
	'Are you sure?' => 'Está seguro?',
	'Privileges' => 'Privilegios',
	'Create user' => 'Crear Usuario',
	'User has been dropped.' => 'Usuario eliminado.',
	'User has been altered.' => 'Usuario modificado.',
	'User has been created.' => 'Usuario creado.',
	'Hashed' => 'Hash',
	'Column' => 'Columna',
	'Routine' => 'Rutina',
	'Grant' => 'Conceder',
	'Revoke' => 'Impedir',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data demasiado grande. Reduzca el tamaño o aumente la directiva de configuración %s.',
	'Logged as: %s' => 'Logeado como: %s',
	'Move up' => 'Mover arriba',
	'Move down' => 'Mover abajo',
	'Functions' => 'Funciones',
	'Aggregation' => 'Agregaciones',
	'Export' => 'Exportar',
	'Output' => 'Salida',
	'open' => 'mostrar',
	'save' => 'archivo',
	'Format' => 'Formato',
	'Tables' => 'Tablas',
	'Data' => 'Datos',
	'Event has been dropped.' => 'Evento eliminado.',
	'Event has been altered.' => 'Evento modificado.',
	'Event has been created.' => 'Evento creado.',
	'Alter event' => 'Modificar Evento',
	'Create event' => 'Crear Evento',
	'At given time' => 'A hora determinada',
	'Every' => 'Cada',
	'Events' => 'Eventos',
	'Schedule' => 'Agenda',
	'Start' => 'Inicio',
	'End' => 'Fin',
	'Status' => 'Estado',
	'On completion preserve' => 'Al completar preservar',
	'Tables and views' => 'Tablas y vistas',
	'Data Length' => 'Longitud de datos',
	'Index Length' => 'Longitud de índice',
	'Data Free' => 'Espacio libre',
	'Collation' => 'Colación',
	'Analyze' => 'Analizar',
	'Optimize' => 'Optimizar',
	'Check' => 'Comprobar',
	'Repair' => 'Reparar',
	'Truncate' => 'Vaciar',
	'Tables have been truncated.' => 'Tablas vaciadas (truncate).',
	'Rows' => 'Registros',
	',' => ' ',
	'Tables have been moved.' => 'Se movieron las tablas.',
	'Move to other database' => 'Mover a otra base de datos',
	'Move' => 'Mover',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Guardar y continuar editando',
	'original' => 'original',
	'Tables have been dropped.' => 'Tablas eliminadas.',
	'%d item(s) have been affected.' => array('%d ítem afectado.', '%d itemes afectados.'),
	'whole result' => 'resultado completo',
	'Clone' => 'Clonar',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => 'Cantida máxima de campos permitidos excedidos. Por favor aumente %s y %s.',
	'Partition by' => 'Particionar por',
	'Partitions' => 'Particiones',
	'Partition name' => 'Nombre de Partición',
	'Values' => 'Valores',
	'%d row(s) have been imported.' => array('%d registro importado.', '%d registros importados.'),
	'anywhere' => 'donde sea',
	'Import' => 'Importar',
	'Stop on error' => 'Parar en caso de error',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[aaaa]',
	'History' => 'History',
	'Variables' => 'Variables',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Las columnas de origen y destino deben ser del mismo tipo, debe existir un índice entre las columnas del destino y el registro referenciado debe existir.',
	'Relations' => 'Relaciones',
	'Run file' => 'Ejecutar Archivo',
	'Clear' => 'Vaciar',
	'Maximum allowed file size is %sB.' => 'Tamaño máximo de archivo es %sB.',
	'Numbers' => 'Números',
	'Date and time' => 'Fecha y hora',
	'Strings' => 'Cadena',
	'Binary' => 'Binario',
	'Lists' => 'Listas',
	'Editor' => 'Editor',
	'E-mail' => 'Email',
	'From' => 'De',
	'Subject' => 'Asunto',
	'Send' => 'Enviar',
	'%d e-mail(s) have been sent.' => array('%d email enviado.', '%d emails enviados.'),
	'Webserver file %s' => 'Archivo de servidor web %s',
	'File does not exist.' => 'Archivo no existe.',
	'%d in total' => '%d en total',
	'Permanent login' => 'Guardar contraseña',
	'Databases have been dropped.' => 'Bases de datos eliminadas.',
	'Search data in tables' => 'Buscar datos en tablas',
	'schema' => 'esquema',
	'Schema' => 'Esquema',
	'Alter schema' => 'Modificar esquema',
	'Create schema' => 'Crear esquema',
	'Schema has been dropped.' => 'Esquema eliminado.',
	'Schema has been created.' => 'Esquema creado.',
	'Schema has been altered.' => 'Esquema modificado.',
	'Sequences' => 'Secuencias',
	'Create sequence' => 'Crear secuencias',
	'Alter sequence' => 'Modificar secuencia',
	'Sequence has been dropped.' => 'Secuencia eliminada.',
	'Sequence has been created.' => 'Secuencia creada.',
	'Sequence has been altered.' => 'Secuencia modificada.',
	'User types' => 'Tipos definido por el usuario',
	'Create type' => 'Crear tipo',
	'Alter type' => 'Modificar tipo',
	'Type has been dropped.' => 'Tipo eliminado.',
	'Type has been created.' => 'Tipo creado.',
	'Double click on a value to modify it.' => 'Doble-clic sobre el valor para editarlo.',
	'Use edit link to modify this value.' => 'Utilice el enlace de modificar para realizar los cambios.',
	'last' => 'último',
	'From server' => 'Desde servidor',
	'System' => 'Motor de base de datos',
	'Select data' => 'Visualizar contenido',
	'Show structure' => 'Mostrar estructura',
	'empty' => 'ningúno',
	'Network' => 'Red',
	'Geometry' => 'Geometría',
	'File exists.' => 'Archivo ya existe.',
	'Attachments' => 'Adjuntos',
	'%d query(s) executed OK.' => array('%d sentencia sql ejecutada correctamente.', '%d sentencias sql ejecutadas correctamente.'),
	'Show only errors' => 'Mostrar solamente errores',
	'Last page' => 'Ultima página',
	'Refresh' => 'Refrescar',
	'Invalid schema.' => 'Esquema inválido.',
	'Please use one of the extensions %s.' => 'Por favor use una de las extensiones %s.',
	'now' => 'ahora',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Tablas copiadas.',
	'Copy' => 'Copiar',
	'Permanent link' => 'Enlace permanente',
	'Edit all' => 'Editar todos',
	'Resend POST data?' => 'Volver a enviar POST data?',
	'HH:MM:SS' => 'HH:MM:SS',
);

==> adminer_4.2.1.orig.tar.gz: adminer-4.2.1/adminer/lang/es.inc.php <==
<?php
$translations = array(
	'Login' => 'Login',
	'Logout successful.' => 'Sesión finalizada con éxito.',
	'Invalid credentials.' => 'Usuario y/o clave de acceso incorrecta.',
	'Server' => 'Servidor',
	'Username' => 'Usuario',
	'Password' => 'Contraseña',
	'Select database' => 'Seleccionar Base de datos',
	'Invalid database.' => 'Base de datos incorrecta.',
	'Create new database' => 'Crear nueva base de datos',
	'Table has been dropped.' => 'Tabla eliminada.',
	'Table has been altered.' => 'Tabla modificada.',
	'Table has been created.' => 'Tabla creada.',
	'Alter table' => 'Modificar tabla',
	'Create table' => 'Crear tabla',
	'Table name' => 'Nombre de la tabla',
	'engine' => 'motor',
	'collation' => 'colación',
	'Column name' => 'Nombre de columna',
	'Type' => 'Tipo',
	'Length' => 'Longitud',
	'Auto Increment' => 'Incremento automático',
	'Options' => 'Opciones',
	'Save' => 'Guardar',
	'Drop' => 'Eliminar',
	'Database has been dropped.' => 'Base de datos eliminada.',
	'Database has been created.' => 'Base de datos creada.',
	'Database has been renamed.' => 'Base de datos renombrada.',
	'Database has been altered.' => 'Base de datos modificada.',
	'Alter database' => 'Modificar Base de datos',
	'Create database' => 'Crear Base de datos',
	'SQL command' => 'Comando SQL',
	'Logout' => 'Cerrar sesión',
	'database' => 'base de datos',
	'Use' => 'Usar',
	'No tables.' => 'No existen tablas.',
	'select' => 'registros',
	'Item has been deleted.' => 'Registro eliminado.',
	'Item has been updated.' => 'Registro modificado.',
	'Item%s has been inserted.' => 'Registro%s insertado.',
	'Edit' => 'Modificar',
	'Insert' => 'Agregar',
	'Save and insert next' => 'Guardar e insertar siguiente',
	'Delete' => 'Eliminar',
	'Database' => 'Base de datos',
	'Routines' => 'Procedimientos',
	'Indexes have been altered.' => 'Indices actualizados.',
	'Indexes' => 'Indices',
	'Alter indexes' => 'Modificar indices',
	'Add next' => 'Agregar',
	'Language' => 'Idioma',
	'Select' => 'Mostrar',
	'New item' => 'Nuevo Registro',
	'Search' => 'Condición',
	'Sort' => 'Ordenar',
	'descending' => 'descendiente',
	'Limit' => 'Limite',
	'No rows.' => 'No existen registros.',
	'Action' => 'Acción',
	'edit' => 'modificar',
	'Page' => 'Página',
	'Query executed OK, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Error in query' => 'Error al ejecutar consulta',
	'Execute' => 'Ejecutar',
	'Table' => 'Tabla',
	'Foreign keys' => 'Claves externas',
	'Triggers' => 'Disparadores',
	'View' => 'Vista',
	'Unable to select the table' => 'No es posible seleccionar la tabla',
	'Invalid CSRF token. Send the form again.' => 'Token CSRF inválido. Vuelva a enviar los datos del formulario.',
	'Comment' => 'Comentario',
	'Default values' => 'Valores predeterminados',
	'%d byte(s)' => array('%d byte', '%d bytes'),
	'No commands to execute.' => 'No es posible ejecutar ningún comando.',
	'Unable to upload a file.' => 'No es posible importar el archivo.',
	'File upload' => 'Importar archivo',
	'File uploads are disabled.' => 'Importación de archivos deshablilitada.',
	'Routine has been called, %d row(s) affected.' => array('Consulta ejecutada, %d registro afectado.', 'Consulta ejecutada, %d registros afectados.'),
	'Call' => 'Llamar',
	'No extension' => 'No hay extension',
	'None of the supported PHP extensions (%s) are available.' => 'Ninguna de las extensiones PHP soportadas (%s) está disponible.',
	'Session support must be enabled.' => 'Deben estar habilitadas las sesiones.',
	'Session expired, please login again.' => 'Sesión caducada, por favor escriba su clave de nuevo.',
	'Text length' => 'Longitud de texto',
	'Foreign key has been dropped.' => 'Clave externa eliminada.',
	'Foreign key has been altered.' => 'Clave externa modificada.',
	'Foreign key has been created.' => 'Clave externa creada.',
	'Foreign key' => 'Clave externa',
	'Target table' => 'Tabla de destino',
	'Change' => 'Modificar',
	'Source' => 'Origen',
	'Target' => 'Destino',
	'Add column' => 'Agregar columna',
	'Alter' => 'Modificar',
	'Add foreign key' => 'Agregar clave externa',
	'ON DELETE' => 'AL BORRAR',
	'ON UPDATE' => 'AL ACTUALIZAR',
	'Index Type' => 'Tipo de índice',
	'Column (length)' => 'Columna (longitud)',
	'View has been dropped.' => 'Vista eliminada.',
	'View has been altered.' => 'Vista modificada.',
	'View has been created.' => 'Vista creada.',
	'Alter view' => 'Modificar vista',
	'Create view' => 'Crear vista',
	'Name' => 'Nombre',
	'Process list' => 'Lista de procesos',
	'%d process(es) have been killed.' => array('%d proceso detenido.', '%d procesos detenidos.'),
	'Kill' => 'Detener',
	'Parameter name' => 'Nombre de Parámetro',
	'Database schema' => 'Esquema de base de datos',
	'Create procedure' => 'Crear procedimiento',
	'Create function' => 'Crear función',
	'Routine has been dropped.' => 'Procedimiento eliminado.',
	'Routine has been altered.' => 'Procedimiento modificado.',
	'Routine has been created.' => 'Procedimiento creado.',
	'Alter function' => 'Modificar Función',
	'Alter procedure' => 'Modificar procedimiento',
	'Return type' => 'Tipo de valor de vuelta',
	'Add trigger' => 'Agregar disparador',
	'Trigger has been dropped.' => 'Disparador eliminado.',
	'Trigger has been altered.' => 'Disparador modificado.',
	'Trigger has been created.' => 'Disparador creado.',
	'Alter trigger' => 'Modificar Disparador',
	'Create trigger' => 'Agregar Disparador',
	'Time' => 'Tiempo',
	'Event' => 'Evento',
	'%s version: %s through PHP extension %s' => 'Versión %s: %s a través de la extensión de PHP %s',
	'%d row(s)' => array('%d registro', '%d registros'),
	'Remove' => 'Eliminar',
	'Are you sure?' => 'Está seguro?',
	'Privileges' => 'Privilegios',
	'Create user' => 'Crear Usuario',
	'User has been dropped.' => 'Usuario eliminado.',
	'User has been altered.' => 'Usuario modificado.',
	'User has been created.' => 'Usuario creado.',
	'Hashed' => 'Hash',
	'Column' => 'Columna',
	'Routine' => 'Rutina',
	'Grant' => 'Conceder',
	'Revoke' => 'Impedir',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => 'POST data demasiado grande. Reduzca el tamaño o aumente la directiva de configuración %s.',
	'Logged as: %s' => 'Logeado como: %s',
	'Move up' => 'Mover arriba',
	'Move down' => 'Mover abajo',
	'Functions' => 'Funciones',
	'Aggregation' => 'Agregados',
	'Export' => 'Exportar',
	'Output' => 'Salida',
	'open' => 'mostrar',
	'save' => 'archivo',
	'Format' => 'Formato',
	'Tables' => 'Tablas',
	'Data' => 'Datos',
	'Event has been dropped.' => 'Evento eliminado.',
	'Event has been altered.' => 'Evento modificado.',
	'Event has been created.' => 'Evento creado.',
	'Alter event' => 'Modificar Evento',
	'Create event' => 'Crear Evento',
	'At given time' => 'En el momento indicado',
	'Every' => 'Cada',
	'Events' => 'Eventos',
	'Schedule' => 'Agenda',
	'Start' => 'Inicio',
	'End' => 'Fin',
	'Status' => 'Estado',
	'On completion preserve' => 'Al completar mantener',
	'Tables and views' => 'Tablas y vistas',
	'Data Length' => 'Longitud de datos',
	'Index Length' => 'Longitud de índice',
	'Data Free' => 'Espacio libre',
	'Collation' => 'Colación',
	'Analyze' => 'Analizar',
	'Optimize' => 'Optimizar',
	'Check' => 'Comprobar',
	'Repair' => 'Reparar',
	'Truncate' => 'Vaciar',
	'Tables have been truncated.' => 'Las tablas han sido vaciadas.',
	'Rows' => 'Registros',
	',' => ' ',
	'0123456789' => '0123456789',
	'Tables have been moved.' => 'Se movieron las tablas.',
	'Move to other database' => 'Mover a otra base de datos',
	'Move' => 'Mover',
	'Engine' => 'Motor',
	'Save and continue edit' => 'Guardar y continuar editando',
	'original' => 'original',
	'Tables have been dropped.' => 'Tablas eliminadas.',
	'%d item(s) have been affected.' => array('%d elemento afectado.', '%d elementos afectados.'),
	'whole result' => 'resultado completo',
	'Clone' => 'Clonar',
	'Maximum number of allowed fields exceeded. Please increase %s.' => 'Excedida la cantidad máxima de campos permitidos. Por favor aumente %s.',
	'Partition by' => 'Particionar por',
	'Partitions' => 'Particiones',
	'Partition name' => 'Nombre de Partición',
	'Values' => 'Valores',
	'%d row(s) have been imported.' => array('%d registro importado.', '%d registros importados.'),
	'anywhere' => 'donde sea',
	'Import' => 'Importar',
	'Stop on error' => 'Parar en caso de error',
	'%.3f s' => '%.3f s',
	'$1-$3-$5' => '$5/$3/$1',
	'[yyyy]-mm-dd' => 'dd/mm/[aaaa]',
	'History' => 'Histórico',
	'Variables' => 'Variables',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => 'Las columnas de origen y destino deben ser del mismo tipo, debe existir un índice entre las columnas del destino y el registro referenciado debe existir también.',
	'Relations' => 'Relaciones',
	'Run file' => 'Ejecutar Archivo',
	'Clear' => 'Vaciar',
	'Maximum allowed file size is %sB.' => 'El tamaño máximo de archivo es %sB.',
	'Numbers' => 'Números',
	'Date and time' => 'Fecha y hora',
	'Strings' => 'Cadena',
	'Binary' => 'Binario',
	'Lists' => 'Listas',
	'Editor' => 'Editor',
	'E-mail' => 'Email',
	'From' => 'De',
	'Subject' => 'Asunto',
	'Send' => 'Enviar',
	'%d e-mail(s) have been sent.' => array('%d email enviado.', '%d emails enviados.'),
	'Webserver file %s' => 'Archivo de servidor web %s',
	'File does not exist.' => 'Ese archivo no existe.',
	'%d in total' => '%d en total',
	'Permanent login' => 'Guardar contraseña',
	'Databases have been dropped.' => 'Bases de datos eliminadas.',
	'Search data in tables' => 'Buscar datos en tablas',
	'Schema' => 'Esquema',
	'Alter schema' => 'Modificar esquema',
	'Create schema' => 'Crear esquema',
	'Schema has been dropped.' => 'Esquema eliminado.',
	'Schema has been created.' => 'Esquema creado.',
	'Schema has been altered.' => 'Esquema modificado.',
	'Sequences' => 'Secuencias',
	'Create sequence' => 'Crear secuencias',
	'Alter sequence' => 'Modificar secuencia',
	'Sequence has been dropped.' => 'Secuencia eliminada.',
	'Sequence has been created.' => 'Secuencia creada.',
	'Sequence has been altered.' => 'Secuencia modificada.',
	'User types' => 'Tipos definidos por el usuario',
	'Create type' => 'Crear tipo',
	'Alter type' => 'Modificar tipo',
	'Type has been dropped.' => 'Tipo eliminado.',
	'Type has been created.' => 'Tipo creado.',
	'Ctrl+click on a value to modify it.' => 'Ctrl+clic sobre el valor para editarlo.',
	'Use edit link to modify this value.' => 'Utilice el enlace de edición para realizar cambios.',
	'last' => 'último',
	'From server' => 'Desde servidor',
	'System' => 'Motor de base de datos',
	'Select data' => 'Visualizar contenido',
	'Show structure' => 'Mostrar estructura',
	'empty' => 'ningúno',
	'Network' => 'Red',
	'Geometry' => 'Geometría',
	'File exists.' => 'Ese archivo ya existe.',
	'Attachments' => 'Adjuntos',
	'%d query(s) executed OK.' => array('%d sentencia sql ejecutada correctamente.', '%d sentencias sql ejecutadas correctamente.'),
	'Show only errors' => 'Mostrar solamente errores',
	'Refresh' => 'Refrescar',
	'Invalid schema.' => 'Esquema inválido.',
	'Please use one of the extensions %s.' => 'Por favor use una de las extensiones %s.',
	'now' => 'ahora',
	'ltr' => 'ltr',
	'Tables have been copied.' => 'Tablas copiadas.',
	'Copy' => 'Copiar',
	'Permanent link' => 'Enlace permanente',
	'Edit all' => 'Editar todos',
	'HH:MM:SS' => 'HH:MM:SS',
);
